@@ -15,6 +15,13 @@ test -x $FIREHOL_LIB && . $FIREHOL_LIB
 
 ##### Helper functions
 
+# require commands for wizard mode
+require_cmd ip
+require_cmd netstat
+require_cmd egrep
+require_cmd date
+require_cmd hostname	
+
 #Ask the questions:
 wizard_ask() {
 	local prompt="${1}"; shift
@@ -291,16 +298,16 @@ helpme_iface() {
 #Prepare the directory:
 mkdir "${FIREHOL_DIR}"
 cd "${FIREHOL_DIR}"
-${MKDIR_CMD} ports
-${MKDIR_CMD} keys
+"${MKDIR_CMD}" ports
+"${MKDIR_CMD}" keys
 cd ports
-${MKDIR_CMD} tcp
-${MKDIR_CMD} udp
+"${MKDIR_CMD}" tcp
+"${MKDIR_CMD}" udp
 
 #Inform the user:
 
-${CAT_CMD} >&2 <<EOF
-$Id: firehol.sh,v 1.214 2004/11/01 00:13:00 ktsaou Exp $
+"${CAT_CMD}" >&2 <<EOF
+$Id: firehol.sh,v 1.231 2004/11/01 00:13:00 ktsaou Exp $
 
 (C) Copyright 2003, Costa Tsaousis <costa@tsaousis.gr>
 FireHOL is distributed under GPL.
@@ -387,7 +394,7 @@ echo "#             *** NEVER USE THIS CONFIG AS-IS ***"
 echo "# "
 
 ${CAT_CMD} <<EOF
-# $Id: firehol.sh,v 1.214 2004/11/01 00:13:00 ktsaou Exp $
+# $Id: firehol.sh,v 1.231 2004/11/01 00:13:00 ktsaou Exp $
 # (C) Copyright 2003, Costa Tsaousis <costa@tsaousis.gr>
 # FireHOL is distributed under GPL.
 # Home Page: http://firehol.sourceforge.net
