@@ -10,68 +10,30 @@
 #
 # config: /etc/firehol/firehol.conf
 #
-# $Id: firehol.sh,v 1.214 2004/11/01 00:13:00 ktsaou Exp $
+# $Id: firehol.sh,v 1.231 2004/11/01 00:13:00 ktsaou Exp $
 #
 
+# Make sure only root can run us.
+if [ ! "${UID}" = 0 ]
+then
+        echo >&2
+        echo >&2
+        echo >&2 "Only user root can run FireHOL."
+        echo >&2
+fi
+
 # Remember who you are.
 FIREHOL_FILE="${0}"
-FIREHOL_DEFAULTFILE="/etc/default/firehol"
+FIREHOL_DEFAULT_WORKING_DIRECTORY="${PWD}"
 FIREHOL_LIB="/lib/firehol/firehol"
 FIREHOL_DEFAULT_WORKING_DIRECTORY="/etc/firehol"
 
-# Find our minor version
-FIREHOL_MINOR_VERSION="`cat "${FIREHOL_FILE}" | grep "^# \\\$Id:" | head -n 1 | cut -d ' ' -f 4 | cut -d '.' -f 2`"
-expr ${FIREHOL_MINOR_VERSION} + 0 >/dev/null 2>&1
-if [ $? -ne 0 ]
-then
-	FIREHOL_MINOR_VERSION=214
-fi
-
-PATH="${PATH}:/bin:/usr/bin:/sbin:/usr/sbin"
+export PATH="${PATH}:/bin:/usr/bin:/sbin:/usr/sbin"
 
 # Get all helper functions:
 
 test -x $FIREHOL_LIB && . $FIREHOL_LIB
 
-# ------------------------------------------------------------------------------
-# Make sure we automatically cleanup when we exit.
-# WHY:
-# Even a CTRL-C will call this and we will not leave temp files.
-# Also, if a configuration file breaks, we will detect this too.
-
-firehol_exit() {
-	
-	if [ -f "${FIREHOL_SAVED}" ]
-	then
-		echo
-		echo -n $"FireHOL: Restoring old firewall:"
-		iptables-restore <"${FIREHOL_SAVED}"
-		if [ $? -eq 0 ]
-		then
-			success $"FireHOL: Restoring old firewall:"
-		else
-			failure $"FireHOL: Restoring old firewall:"
-		fi
-		echo
-	fi
-	
-	test -d "${FIREHOL_DIR}" && ${RM_CMD} -rf "${FIREHOL_DIR}"
-	return 0
-}
-
-# Run our exit even if we don't call exit.
-trap firehol_exit EXIT
-
-test -d "${FIREHOL_DIR}" && ${RM_CMD} -rf "${FIREHOL_DIR}"
-${MKDIR_CMD} -p "${FIREHOL_DIR}"
-test $? -gt 0 && exit 1
-
-${MKDIR_CMD} -p "${FIREHOL_CHAINS_DIR}"
-test $? -gt 0 && exit 1
-
-
-
-
 # ------------------------------------------------------------------------------
 # XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
 # ------------------------------------------------------------------------------
@@ -310,7 +272,7 @@ case "${arg}" in
 		else
 		
 		${CAT_CMD} <<EOF
-$Id: firehol.sh,v 1.214 2004/11/01 00:13:00 ktsaou Exp $
+$Id: firehol.sh,v 1.231 2004/11/01 00:13:00 ktsaou Exp $
 (C) Copyright 2003, Costa Tsaousis <costa@tsaousis.gr>
 FireHOL is distributed under GPL.
 
@@ -482,7 +444,7 @@ then
 	
 	${CAT_CMD} <<EOF
 
-$Id: firehol.sh,v 1.214 2004/11/01 00:13:00 ktsaou Exp $
+$Id: firehol.sh,v 1.231 2004/11/01 00:13:00 ktsaou Exp $
 (C) Copyright 2003, Costa Tsaousis <costa@tsaousis.gr>
 FireHOL is distributed under GPL.
 Home Page: http://firehol.sourceforge.net
@@ -675,8 +637,8 @@ done
 ${IPTABLES_CMD} -t filter -P INPUT "\${FIREHOL_INPUT_ACTIVATION_POLICY}" >${FIREHOL_OUTPUT}.log 2>&1
 r=\$?; test ! \${r} -eq 0 && runtime_error error \${r} INIT ${IPTABLES_CMD} -t filter -P INPUT "\${FIREHOL_INPUT_ACTIVATION_POLICY}"
 
-${IPTABLES_CMD} -t filter -P INPUT "\${FIREHOL_OUTPUT_ACTIVATION_POLICY}" >${FIREHOL_OUTPUT}.log 2>&1
-r=\$?; test ! \${r} -eq 0 && runtime_error error \${r} INIT ${IPTABLES_CMD} -t filter -P INPUT "\${FIREHOL_OUTPUT_ACTIVATION_POLICY}"
+${IPTABLES_CMD} -t filter -P OUTPUT "\${FIREHOL_OUTPUT_ACTIVATION_POLICY}" >${FIREHOL_OUTPUT}.log 2>&1
+r=\$?; test ! \${r} -eq 0 && runtime_error error \${r} INIT ${IPTABLES_CMD} -t filter -P OUTPUT "\${FIREHOL_OUTPUT_ACTIVATION_POLICY}"
 
 ${IPTABLES_CMD} -t filter -P FORWARD "\${FIREHOL_FORWARD_ACTIVATION_POLICY}" >${FIREHOL_OUTPUT}.log 2>&1
 r=\$?; test ! \${r} -eq 0 && runtime_error error \${r} INIT ${IPTABLES_CMD} -t filter -P FORWARD "\${FIREHOL_FORWARD_ACTIVATION_POLICY}"
@@ -730,6 +692,7 @@ ${CAT_CMD} >"${FIREHOL_TMP}.awk" <<"EOF"
 /^[[:space:]]*tcpmss[[:space:]]/ { printf "FIREHOL_LINEID=${LINENO} " }
 /^[[:space:]]*tos[[:space:]]/ { printf "FIREHOL_LINEID=${LINENO} " }
 /^[[:space:]]*transparent_squid[[:space:]]/ { printf "FIREHOL_LINEID=${LINENO} " }
+/^[[:space:]]*transparent_proxy[[:space:]]/ { printf "FIREHOL_LINEID=${LINENO} " }
 { print }
 EOF
 
